@@ -8,6 +8,8 @@ from cased_django.conf import (
     sensitive_data_handlers,
     sensitive_fields,
     log_level,
+    redact_before_publishing,
+    clear_context_after_publishing,
 )
 
 
@@ -20,6 +22,8 @@ def get_cased_client():
     cased.sensitive_data_handlers = sensitive_data_handlers
     cased.sensitive_fields = sensitive_fields
     cased.log_level = log_level
+    cased.redact_before_publishing = redact_before_publishing
+    cased.clear_context_after_publishing = clear_context_after_publishing
     return cased
 
 
