@@ -14,3 +14,9 @@ include_ip_address = getattr(settings, "CASED_INCLUDE_IP_ADDRESS", False)
 reliability_backend = getattr(settings, "CASED_RELIABILITY_BACKEND", None)
 sensitive_data_handlers = getattr(settings, "CASED_SENSITIVE_DATA_HANDLERS", [])
 sensitive_fields = getattr(settings, "CASED_SENSITIVE_FIELDS", set())
+
+redact_before_publishing = getattr(settings, "CASED_REDACT_BEFORE_PUBLISHING", False)
+
+clear_context_after_publishing = getattr(
+    settings, "CASED_CLEAR_CONTEXT_AFTER_PUBLISHING", False
+)
